==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation(
    public val efsFileLocation:
    WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocation? = null,
    public val s3FileLocation:
    WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationS3FileLocation? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation):
            WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation =
            WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation(
    public val efsFileLocation: WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocation? = null,
    public val s3FileLocation: WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationS3FileLocation? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation): WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation =
            WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
